@@ -52,6 +52,19 @@ class WiFiInfo(BaseModel):
     """System settings for WiFi."""
 
     interface: str
+    bridge: str
+    enable_wpa3: bool
+
+    class Config:
+        """Pydantic config."""
+
+        extra = "forbid"
+
+
+class SystemInfo(BaseModel):
+    """System settings that don't find elsewhere."""
+
+    cache_dir: Path
 
     class Config:
         """Pydantic config."""
@@ -65,6 +78,7 @@ class AstoriaConfig(BaseModel):
     mqtt: MQTTBrokerInfo
     kit: KitInfo
     wifi: WiFiInfo
+    system: SystemInfo
 
     class Config:
         """Pydantic config."""
